@@ -1,7 +1,7 @@
 package App::fatten;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-04-07'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -346,7 +346,7 @@ _
             'x.schema.element_entity' => 'distname',
         },
         exclude_core => {
-            summary => 'Exclude core modules',
+            summary => 'Whether to exclude core modules',
             'summary.alt.bool.not' => 'Do not exclude core modules',
             schema => ['bool' => default => 1],
             tags => ['category:module-selection'],
@@ -368,6 +368,7 @@ _
         overwrite => {
             schema => [bool => default => 0],
             summary => 'Whether to overwrite output if previously exists',
+            'summary.alt.bool.yes' => 'Overwrite output if previously exists',
             tags => ['category:output'],
         },
         trace_method => {
@@ -430,18 +431,21 @@ _
 
         squish => {
             summary => 'Whether to squish included modules using Perl::Squish',
+            'summary.alt.bool.yes' => 'Squish included modules using Perl::Squish',
             schema => ['bool' => default=>0],
             tags => ['category:stripping'],
         },
 
         strip => {
             summary => 'Whether to strip included modules using Perl::Strip',
+            'summary.alt.bool.yes' => 'Strip included modules using Perl::Strip',
             schema => ['bool' => default=>0],
             tags => ['category:stripping'],
         },
 
         stripper => {
             summary => 'Whether to strip included modules using Perl::Stripper',
+            'summary.alt.bool.yes' => 'Strip included modules using Perl::Stripper',
             schema => ['bool' => default=>0],
             tags => ['category:stripping'],
         },
@@ -647,7 +651,7 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.31 of App::fatten (from Perl distribution App-fatten), released on 2015-04-02.
+This document describes version 0.32 of App::fatten (from Perl distribution App-fatten), released on 2015-04-07.
 
 =head1 SYNOPSIS
 
@@ -659,6 +663,8 @@ This distribution provides command-line utility called L<fatten>.
 
 =back
 
+=for Pod::Coverage ^(new)$
+
 =head1 FUNCTIONS
 
 
@@ -696,7 +702,7 @@ When you don't want to include a module, specify it here.
 
 =item * B<exclude_core> => I<bool> (default: 1)
 
-Exclude core modules.
+Whether to exclude core modules.
 
 =item * B<exclude_dist> => I<array[str]>
 
@@ -839,8 +845,6 @@ that contains extra information.
 
 Return value:  (any)
 
-=for Pod::Coverage ^(new)$
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-fatten>.
